"""Module implementing different stochastic differential equations as numba jit functions.

Originally implemented in the abandoned project `uit_scripts`, in the `runge_kutta_SDE`
module. Re-formatted with type hints and re-implemented in `fpp_sle` module.
"""
from fpp_sle.sde.runge_kutta_sde import *  # noqa: F401, F403
